# C8-target-c8collection

A [Singer](https://singer.io) target that writes data to ([C8DB](https://macrometa.com/docs/c8ql/)) collections.

## How to use it

`c8_target_c8collection` works together with any other [Singer Tap] to move data from sources like [Braintree], [Freshdesk] and [Hubspot] to JSONL formatted files.

---

